@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 761 $
+# Revision: $Rev: 766 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -68,7 +68,7 @@ class ListViewRecord(QListView):
         self.setColumnWidthMode( 0, QListView.Maximum )
         self.setColumnWidthMode( 1, QListView.Maximum )
         self.setResizeMode( QListView.LastColumn )
-        self.setSelectionMode( QListView.Single )
+        self.setSelectionMode( QListView.Extended )
         self.setDefaultRenameAction( QListView.Accept )
 
         # runtime variables
@@ -202,6 +202,16 @@ class ListViewRecord(QListView):
         self.obj = obj
 
 
+    def getSelectedRecords(self):
+        """returns a list of selected records IDs"""
+        selected = []
+        for obj in self.items.keys():
+            if (obj.isSelected()):
+                selected.append(self.items[obj]['number'])
+
+        return selected
+    
+
     def getCurrentRecord(self):
         """returns the current record"""
         # this test fails:
