@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 760 $
+# Revision: $Rev: 766 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -38,7 +38,7 @@ import defaults
 CONFIG_TEXT = """\
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 760 $
+# Revision: $Rev: 766 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -392,6 +392,7 @@ defaultScript = %(defaultScript)s
 # 
 export = %(export)s
 
+exportDefaultSortKey = %(exportDefaultSortKey)s
 
 #-- EOF --
 """
@@ -411,6 +412,8 @@ class _Settings0(dict):
                      'CatalogueProperties'   : logging.DEBUG,
                      'ChangeNumberDialog'    : logging.DEBUG,
                      'DragObject'            : logging.DEBUG,
+                     'ExportDialog'          : logging.DEBUG,
+                     'ExportProgressDialog'  : logging.DEBUG,
                      'FindDialog'            : logging.DEBUG,
                      'Interface'             : logging.DEBUG,
                      'IODeviceBuffer'        : logging.DEBUG,
@@ -537,7 +540,10 @@ class _Settings0(dict):
                     ),
                    },
         
-        'defaultScript': '[Merkosh Special]',       
+        'defaultScript': '[Merkosh Special]',
+
+        'export': {},
+        'exportDefaultSortKey': '',
         }
     
     def __init__(self, *args, **kwargs):
@@ -621,17 +627,18 @@ class _Settings2(_Settings1):
     def __init__(self):
         super(_Settings2, self).__init__()
 
+
     def selfUpdate(self, toDict, fromDict):
         super(_Settings2, self).selfUpdate(toDict, fromDict)
 
         # add new log class
-        self['version'] = '0.2'
-        self['logLevel']['PictureDockWindow'] = logging.DEBUG
-        self['logLevel']['ExportDialog'] = logging.DEBUG
+        if (self['version'] == '0.1'):
+            self['version'] = '0.2'
+
+            # add export settings
+            self['export'] = {u'simple PDF': (u'genLatexExport.bash', u'simple_pdf.st', u'/tmp/simple_pdf.pdf')}
+            self['exportDefaultSortKey'] = 'mediaLabel'
 
-        # add export settings
-        self['export'] = {u'LaTex /PDF': u'pytex.py templates/merkosh_pdf_template.tex /tmp/merkosh_pdf.tex; pdflatex /tmp/merkosh_pdf.tex', }
-        
 
     def asText(self):
         """returns a dict which interpolates configText"""
@@ -639,7 +646,7 @@ class _Settings2(_Settings1):
         defs = super(_Settings2, self).asText()
 
         # interpolate export settings
-        for key in ['export']:
+        for key in ['export', 'exportDefaultSortKey']:
             defs[key] = pformat(self[key])
 
         # return result
@@ -744,6 +751,7 @@ class _Pref(dict):
     def update(self, pref):
         """updates the own contents, given a template"""
         self.clear()
+
         # update simple values
         for key in ['defaultPath', 'defaultMoviePath', 'browserPath', 'proxy',
                     'systemEncoding', 'recordStoreOrderRandom', 'mediaInfo',
@@ -753,7 +761,8 @@ class _Pref(dict):
                     'defaultHistory', 'addHistoryFromRecords', 'recordDefault',
                     'autoScanAutoMountOnNew', 'autoScanOnNew', 'autoScriptOnNew',
                     'deepcopyOnCopy', 'defaultFile', 'reopenLastFile',
-                    'recentFiles', 'queryPathOnLinkedImage', 'version']:
+                    'recentFiles', 'queryPathOnLinkedImage', 'version',
+                    'export', 'exportDefaultSortKey']:
             self[key] = deepcopy(pref[key])
 
         # debug info on a per-class basis
@@ -807,4 +816,4 @@ if (__name__ == '__main__'):
     a = Settings()
     a.save()
     b = getPreferences()
-<
+
