@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 692 $
+# Revision: $Rev: 766 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -24,15 +24,16 @@ import os
 from os.path import join as fjoin, exists as fexists
 
 
-pythondir = "${prefix}/lib/python2.4/site-packages".replace('${prefix}', "prefix")
+pythondir = "${prefix}/lib/python2.4/site-packages".replace('${prefix}', "/usr")
 installdir = fjoin(pythondir, "lmc")
 
 if (os.getcwd() == "/home/merkosh/src/lmc/src"):
-	installdir = "."
+	installdir = "/home/merkosh/src/lmc/src"
 
-version = "0.13"
+version = "0.14"
 scriptdir = fjoin(installdir, "scripts")
 resourcedir = fjoin(installdir, "resources")
+templatedir = fjoin(installdir, "templates")
 
 use_listviewsort = ("yes" == "yes")
 
