@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 761 $
+# Revision: $Rev: 766 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -32,11 +32,13 @@ import sys
 import os
 import logging
 import time
+import shutil
 
 from types import ListType
 from os.path import dirname, basename, exists as fexists, samefile, \
-     getsize as fsize, splitext, join as fjoin
+     getsize as fsize, splitext, join as fjoin, splitext
 from copy import deepcopy
+from popen2 import popen2
 
 
 #-- create logging and load preferences ----------------------------------------
@@ -48,14 +50,14 @@ log.addHandler(hdlr)
 log.setLevel(logging.DEBUG)             # default log level
 
 # output program text-logo
-log.info("moviefly  $Rev: 761 $ (c) by Uwe Mayer")
+log.info("moviefly  $Rev: 766 $ (c) by Uwe Mayer")
 
 
 #-- own imports --
 import Settings
 import MediaInfo
 
-from defaults import scriptdir, version
+from defaults import scriptdir, templatedir, version
 
 from LMCWidgetBase import LMCWidgetBase
 from AMCFile33 import AMCFile33, AMCRecord33
@@ -69,6 +71,8 @@ from StdIOProcess import StdIOProcess
 from FindDialog import FindDialog
 from CatalogueProperties import CatalogueProperties
 from ChangeNumberDialog import ChangeNumberDialog
+from ExportDialog import ExportDialog
+from ExportProgressDialog import ExportProgressDialog
 
 
 # load settings
@@ -291,6 +295,84 @@ class LMCMain(LMCWidgetBase):
         self.fileOpen(filename)
 
 
+    def fileExport(self):
+        """called when exporting current selection"""
+        # create export dialog
+        dlg = ExportDialog(self)
+        if (dlg.exec_loop() == ExportDialog.Rejected): return
+        (exportFilter, sortKey, allEntries, reversed) = dlg.getOptions()
+
+        # get selected records, if required
+        selectedList = []
+        if (not allEntries):
+            selectedList = self.centralWidget().getSelectedRecords()
+
+        # select records required for sorting
+        # (<sort-criterea>,<linear-file-index>)
+        sortList = []
+        recIdx = 0                      # not ID, but linear index into file
+        for rec in self.__file:
+            if (allEntries or (rec['number'] in selectedList)):
+                sortList.append((rec[sortKey],recIdx))
+            recIdx = recIdx+1
+            
+        # do lexicographic or numerical sort
+        self.log.debug('Sorting entries for export')
+        sortFcn = lambda a,b: cmp(a[0].lower(),b[0].lower())
+        if (sortKey in ['number', 'date', 'rating', 'year', 'length',
+                        'videoBitrate', 'audioBitrate', 'discs',
+                        'checked']):
+            sortFcn = lambda a,b: int(a[0] - b[0])
+        sortList.sort(sortFcn, None, reversed)
+
+        # call ouptut script
+        filterCommand  = pref['export'][exportFilter][0]
+        filterTemplate = pref['export'][exportFilter][1]
+        targetFile     = pref['export'][exportFilter][2]
+
+        # remove target file, if exists
+        if (fexists(targetFile)):
+            os.unlink(targetFile)    
+
+        exportScript = StdIOProcess(filterCommand,
+                                    [fjoin(templatedir,filterTemplate),
+                                     unicode(self.__file.name).encode(pref['systemEncoding'])],
+                                    os.environ, scriptdir)
+        paramList = [unicode(x[1]) for x in sortList]
+        execDlg = ExportProgressDialog(exportScript, paramList, modal=True)
+
+        # if process was aborted, stop
+        if (execDlg.exec_loop() == execDlg.Rejected):
+            self.log.info("Export aborted")
+            return
+
+        print exportScript.stdout()
+        
+        # query user for final destination of output file
+        if (fexists(targetFile)):
+            fileExt    = splitext(targetFile)[1]
+            dlg = QFileDialog(self.lastFolder, "*"+fileExt, self)
+            dlg.setCaption(self.tr("Save exported file as"))
+            dlg.setViewMode(QFileDialog.Detail)
+            dlg.setMode(QFileDialog.AnyFile)
+            
+            if (dlg.exec_loop() == QFileDialog.Rejected): return
+            filename = unicode(dlg.selectedFile())
+            if (splitext(filename)[1] == ''):
+                filename = filename+fileExt
+        
+            # copy file to destination
+            shutil.move(targetFile, filename)
+
+        # target file does not exist -> error
+        else:
+            dlg = QMessageBox.critical(self, "Error during export...",
+                                          "The target file %s does not exist. Please<br>"+
+                                          "check the debug output for further details.",
+                                          QMessageBox.Ok)
+            dlg.exec_loop()
+        
+
     def fileClose(self):
         """closes a file and removes the central widget"""
         self.log.info("Closing file %s", self.__file.name)
@@ -1035,11 +1117,13 @@ class LMCMain(LMCWidgetBase):
         self.disconnect(self.togglePicturePreviewAction, SIGNAL("toggled(bool)"), self.togglePicturePreview)
 
         
-        
 
     def _enableFileActions(self):
         """enables Save, SaveAs and Close actions"""
         self.log.debug("Enabling file actions")
+
+        self.connect(self.fileExportAction, SIGNAL("activated()"), self.fileExport)
+        self.fileExportAction.setEnabled(True)
         
         self.connect(self.fileCloseAction, SIGNAL("activated()"), self.fileClose)
         self.fileCloseAction.setEnabled(True)
@@ -1075,6 +1159,9 @@ class LMCMain(LMCWidgetBase):
     def _disableFileActions(self):
         """disables Save, SaveAs and Close actions"""
         self.log.debug("Disabling file actions")
+
+        self.fileExportAction.setEnabled(False)
+        self.disconnect(self.fileExportAction, SIGNAL("activated()"), self.fileExport)
         
         self.fileCloseAction.setEnabled(False)
         self.disconnect(self.fileCloseAction, SIGNAL("activated()"), self.fileClose)
@@ -1273,7 +1360,7 @@ Synopsis: lmc.py [-h|--help] [<input-file>]
 elif (('-v' in app.argv()[1:]) or ('--version' in app.argv()[1:])):
     print "Moviefly  (c) by Uwe Mayer"
     print "Version:  %s"%version
-    print "Revision: $Rev: 761 $"
+    print "Revision: $Rev: 766 $"
     print 
     sys.exit()
     
